Class: Google::Apis::Adexchangebuyer2V2beta1::Creative

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Overview

A creative and its classification data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Creative

Returns a new instance of Creative.



815
816
817
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

The account that this creative belongs to. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property accountId

Returns:

  • (String)


668
669
670
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 668

def 
  @account_id
end

#ad_choices_destination_urlString

The link to AdChoices destination page. Corresponds to the JSON property adChoicesDestinationUrl

Returns:

  • (String)


673
674
675
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 673

def ad_choices_destination_url
  @ad_choices_destination_url
end

#ad_technology_providersGoogle::Apis::Adexchangebuyer2V2beta1::AdTechnologyProviders

Detected ad technology provider information. Corresponds to the JSON property adTechnologyProviders



678
679
680
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 678

def ad_technology_providers
  @ad_technology_providers
end

#advertiser_nameString

The name of the company being advertised in the creative. Corresponds to the JSON property advertiserName

Returns:

  • (String)


683
684
685
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 683

def advertiser_name
  @advertiser_name
end

#agency_idFixnum

The agency ID for this creative. Corresponds to the JSON property agencyId

Returns:

  • (Fixnum)


688
689
690
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 688

def agency_id
  @agency_id
end

#api_update_timeString

Output only. The last update timestamp of the creative through the API. Corresponds to the JSON property apiUpdateTime

Returns:

  • (String)


693
694
695
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 693

def api_update_time
  @api_update_time
end

#attributesArray<String>

All attributes for the ads that may be shown from this creative. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property attributes

Returns:

  • (Array<String>)


699
700
701
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 699

def attributes
  @attributes
end

#click_through_urlsArray<String>

The set of destination URLs for the creative. Corresponds to the JSON property clickThroughUrls

Returns:

  • (Array<String>)


704
705
706
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 704

def click_through_urls
  @click_through_urls
end

#correctionsArray<Google::Apis::Adexchangebuyer2V2beta1::Correction>

Output only. Shows any corrections that were applied to this creative. Corresponds to the JSON property corrections



709
710
711
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 709

def corrections
  @corrections
end

#creative_idString

The buyer-defined creative ID of this creative. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property creativeId

Returns:

  • (String)


715
716
717
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 715

def creative_id
  @creative_id
end

#deals_statusString

Output only. The top-level deals status of this creative. If disapproved, an entry for 'auctionType=DIRECT_DEALS' (or 'ALL') in serving_restrictions will also exist. Note that this may be nuanced with other contextual restrictions, in which case, it may be preferable to read from serving_restrictions directly. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property dealsStatus

Returns:

  • (String)


724
725
726
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 724

def deals_status
  @deals_status
end

#declared_click_through_urlsArray<String>

The set of declared destination URLs for the creative. Corresponds to the JSON property declaredClickThroughUrls

Returns:

  • (Array<String>)


729
730
731
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 729

def declared_click_through_urls
  @declared_click_through_urls
end

#detected_advertiser_idsArray<Fixnum>

Output only. Detected advertiser IDs, if any. Corresponds to the JSON property detectedAdvertiserIds

Returns:

  • (Array<Fixnum>)


734
735
736
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 734

def detected_advertiser_ids
  @detected_advertiser_ids
end

#detected_domainsArray<String>

Output only. The detected domains for this creative. Corresponds to the JSON property detectedDomains

Returns:

  • (Array<String>)


739
740
741
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 739

def detected_domains
  @detected_domains
end

#detected_languagesArray<String>

Output only. The detected languages for this creative. The order is arbitrary. The codes are 2 or 5 characters and are documented at https://developers. google.com/adwords/api/docs/appendix/languagecodes. Corresponds to the JSON property detectedLanguages

Returns:

  • (Array<String>)


746
747
748
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 746

def detected_languages
  @detected_languages
end

#detected_product_categoriesArray<Fixnum>

Output only. Detected product categories, if any. See the ad-product- categories.txt file in the technical documentation for a list of IDs. Corresponds to the JSON property detectedProductCategories

Returns:

  • (Array<Fixnum>)


752
753
754
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 752

def detected_product_categories
  @detected_product_categories
end

#detected_sensitive_categoriesArray<Fixnum>

Output only. Detected sensitive categories, if any. See the ad-sensitive- categories.txt file in the technical documentation for a list of IDs. You should use these IDs along with the excluded-sensitive-category field in the bid request to filter your bids. Corresponds to the JSON property detectedSensitiveCategories

Returns:

  • (Array<Fixnum>)


760
761
762
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 760

def detected_sensitive_categories
  @detected_sensitive_categories
end

#htmlGoogle::Apis::Adexchangebuyer2V2beta1::HtmlContent

HTML content for a creative. Corresponds to the JSON property html



765
766
767
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 765

def html
  @html
end

#impression_tracking_urlsArray<String>

The set of URLs to be called to record an impression. Corresponds to the JSON property impressionTrackingUrls

Returns:

  • (Array<String>)


770
771
772
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 770

def impression_tracking_urls
  @impression_tracking_urls
end

#nativeGoogle::Apis::Adexchangebuyer2V2beta1::NativeContent

Native content for a creative. Corresponds to the JSON property native



775
776
777
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 775

def native
  @native
end

#open_auction_statusString

Output only. The top-level open auction status of this creative. If disapproved, an entry for 'auctionType = OPEN_AUCTION' (or 'ALL') in serving_restrictions will also exist. Note that this may be nuanced with other contextual restrictions, in which case, it may be preferable to read from serving_restrictions directly. Can be used to filter the response of the creatives.list method. Corresponds to the JSON property openAuctionStatus

Returns:

  • (String)


785
786
787
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 785

def open_auction_status
  @open_auction_status
end

#restricted_categoriesArray<String>

All restricted categories for the ads that may be shown from this creative. Corresponds to the JSON property restrictedCategories

Returns:

  • (Array<String>)


790
791
792
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 790

def restricted_categories
  @restricted_categories
end

#serving_restrictionsArray<Google::Apis::Adexchangebuyer2V2beta1::ServingRestriction>

Output only. The granular status of this ad in specific contexts. A context here relates to where something ultimately serves (for example, a physical location, a platform, an HTTPS versus HTTP request, or the type of auction). Corresponds to the JSON property servingRestrictions



797
798
799
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 797

def serving_restrictions
  @serving_restrictions
end

#vendor_idsArray<Fixnum>

All vendor IDs for the ads that may be shown from this creative. See https:// storage.googleapis.com/adx-rtb-dictionaries/vendors.txt for possible values. Corresponds to the JSON property vendorIds

Returns:

  • (Array<Fixnum>)


803
804
805
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 803

def vendor_ids
  @vendor_ids
end

#versionFixnum

Output only. The version of this creative. Corresponds to the JSON property version

Returns:

  • (Fixnum)


808
809
810
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 808

def version
  @version
end

#videoGoogle::Apis::Adexchangebuyer2V2beta1::VideoContent

Video content for a creative. Corresponds to the JSON property video



813
814
815
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 813

def video
  @video
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 820

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @ad_choices_destination_url = args[:ad_choices_destination_url] if args.key?(:ad_choices_destination_url)
  @ad_technology_providers = args[:ad_technology_providers] if args.key?(:ad_technology_providers)
  @advertiser_name = args[:advertiser_name] if args.key?(:advertiser_name)
  @agency_id = args[:agency_id] if args.key?(:agency_id)
  @api_update_time = args[:api_update_time] if args.key?(:api_update_time)
  @attributes = args[:attributes] if args.key?(:attributes)
  @click_through_urls = args[:click_through_urls] if args.key?(:click_through_urls)
  @corrections = args[:corrections] if args.key?(:corrections)
  @creative_id = args[:creative_id] if args.key?(:creative_id)
  @deals_status = args[:deals_status] if args.key?(:deals_status)
  @declared_click_through_urls = args[:declared_click_through_urls] if args.key?(:declared_click_through_urls)
  @detected_advertiser_ids = args[:detected_advertiser_ids] if args.key?(:detected_advertiser_ids)
  @detected_domains = args[:detected_domains] if args.key?(:detected_domains)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @detected_product_categories = args[:detected_product_categories] if args.key?(:detected_product_categories)
  @detected_sensitive_categories = args[:detected_sensitive_categories] if args.key?(:detected_sensitive_categories)
  @html = args[:html] if args.key?(:html)
  @impression_tracking_urls = args[:impression_tracking_urls] if args.key?(:impression_tracking_urls)
  @native = args[:native] if args.key?(:native)
  @open_auction_status = args[:open_auction_status] if args.key?(:open_auction_status)
  @restricted_categories = args[:restricted_categories] if args.key?(:restricted_categories)
  @serving_restrictions = args[:serving_restrictions] if args.key?(:serving_restrictions)
  @vendor_ids = args[:vendor_ids] if args.key?(:vendor_ids)
  @version = args[:version] if args.key?(:version)
  @video = args[:video] if args.key?(:video)
end