Class: Google::Apis::Adexchangebuyer2V2beta1::Deal
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::Deal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
A deal represents a segment of inventory for displaying ads on. A proposal can contain multiple deals. A deal contains the terms and targeting information that is used for serving.
Instance Attribute Summary collapse
-
#available_end_time ⇒ String
Proposed flight end time of the deal.
-
#available_start_time ⇒ String
Optional.
-
#buyer_private_data ⇒ Google::Apis::Adexchangebuyer2V2beta1::PrivateData
Buyers are allowed to store certain types of private data in a proposal/deal.
-
#create_product_id ⇒ String
The product ID from which this deal was created.
-
#create_product_revision ⇒ Fixnum
Optional.
-
#create_time ⇒ String
Output only.
-
#creative_pre_approval_policy ⇒ String
Output only.
-
#creative_restrictions ⇒ Google::Apis::Adexchangebuyer2V2beta1::CreativeRestrictions
Represents creative restrictions associated to Programmatic Guaranteed/ Preferred Deal in Ad Manager.
-
#creative_safe_frame_compatibility ⇒ String
Output only.
-
#deal_id ⇒ String
Output only.
-
#deal_serving_metadata ⇒ Google::Apis::Adexchangebuyer2V2beta1::DealServingMetadata
Message captures metadata about the serving status of a deal.
-
#deal_terms ⇒ Google::Apis::Adexchangebuyer2V2beta1::DealTerms
The deal terms specify the details of a Product/deal.
-
#delivery_control ⇒ Google::Apis::Adexchangebuyer2V2beta1::DeliveryControl
Message contains details about how the deals will be paced.
-
#description ⇒ String
Description for the deal terms.
-
#display_name ⇒ String
The name of the deal.
-
#external_deal_id ⇒ String
Output only.
-
#is_setup_complete ⇒ Boolean
(also: #is_setup_complete?)
Output only.
-
#programmatic_creative_source ⇒ String
Output only.
-
#proposal_id ⇒ String
Output only.
-
#seller_contacts ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ContactInformation>
Output only.
-
#syndication_product ⇒ String
The syndication product associated with the deal.
-
#targeting ⇒ Google::Apis::Adexchangebuyer2V2beta1::MarketplaceTargeting
Targeting represents different criteria that can be used by advertisers to target ad inventory.
-
#targeting_criterion ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::TargetingCriteria>
The shared targeting visible to buyers and sellers.
-
#update_time ⇒ String
Output only.
-
#web_property_code ⇒ String
The web property code for the seller copied over from the product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deal
constructor
A new instance of Deal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deal
Returns a new instance of Deal.
1316 1317 1318 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1316 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_end_time ⇒ String
Proposed flight end time of the deal. This will generally be stored in a
granularity of a second. A value is not required for Private Auction deals or
Preferred Deals.
Corresponds to the JSON property availableEndTime
1171 1172 1173 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1171 def available_end_time @available_end_time end |
#available_start_time ⇒ String
Optional. Proposed flight start time of the deal. This will generally be
stored in the granularity of one second since deal serving starts at seconds
boundary. Any time specified with more granularity (for example, in
milliseconds) will be truncated towards the start of time in seconds.
Corresponds to the JSON property availableStartTime
1179 1180 1181 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1179 def available_start_time @available_start_time end |
#buyer_private_data ⇒ Google::Apis::Adexchangebuyer2V2beta1::PrivateData
Buyers are allowed to store certain types of private data in a proposal/deal.
Corresponds to the JSON property buyerPrivateData
1184 1185 1186 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1184 def buyer_private_data @buyer_private_data end |
#create_product_id ⇒ String
The product ID from which this deal was created. Note: This field may be set
only when creating the resource. Modifying this field while updating the
resource will result in an error.
Corresponds to the JSON property createProductId
1191 1192 1193 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1191 def create_product_id @create_product_id end |
#create_product_revision ⇒ Fixnum
Optional. Revision number of the product that the deal was created from. If
present on create, and the server product_revision has advanced since the
passed-in create_product_revision, an ABORTED error will be returned. Note:
This field may be set only when creating the resource. Modifying this field
while updating the resource will result in an error.
Corresponds to the JSON property createProductRevision
1200 1201 1202 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1200 def create_product_revision @create_product_revision end |
#create_time ⇒ String
Output only. The time of the deal creation.
Corresponds to the JSON property createTime
1205 1206 1207 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1205 def create_time @create_time end |
#creative_pre_approval_policy ⇒ String
Output only. Specifies the creative pre-approval policy.
Corresponds to the JSON property creativePreApprovalPolicy
1210 1211 1212 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1210 def creative_pre_approval_policy @creative_pre_approval_policy end |
#creative_restrictions ⇒ Google::Apis::Adexchangebuyer2V2beta1::CreativeRestrictions
Represents creative restrictions associated to Programmatic Guaranteed/
Preferred Deal in Ad Manager. This doesn't apply to Private Auction and AdX
Preferred Deals.
Corresponds to the JSON property creativeRestrictions
1217 1218 1219 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1217 def creative_restrictions @creative_restrictions end |
#creative_safe_frame_compatibility ⇒ String
Output only. Specifies whether the creative is safeFrame compatible.
Corresponds to the JSON property creativeSafeFrameCompatibility
1222 1223 1224 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1222 def creative_safe_frame_compatibility @creative_safe_frame_compatibility end |
#deal_id ⇒ String
Output only. A unique deal ID for the deal (server-assigned).
Corresponds to the JSON property dealId
1227 1228 1229 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1227 def deal_id @deal_id end |
#deal_serving_metadata ⇒ Google::Apis::Adexchangebuyer2V2beta1::DealServingMetadata
Message captures metadata about the serving status of a deal.
Corresponds to the JSON property dealServingMetadata
1232 1233 1234 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1232 def @deal_serving_metadata end |
#deal_terms ⇒ Google::Apis::Adexchangebuyer2V2beta1::DealTerms
The deal terms specify the details of a Product/deal. They specify things like
price per buyer, the type of pricing model (for example, fixed price, auction)
and expected impressions from the publisher.
Corresponds to the JSON property dealTerms
1239 1240 1241 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1239 def deal_terms @deal_terms end |
#delivery_control ⇒ Google::Apis::Adexchangebuyer2V2beta1::DeliveryControl
Message contains details about how the deals will be paced.
Corresponds to the JSON property deliveryControl
1244 1245 1246 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1244 def delivery_control @delivery_control end |
#description ⇒ String
Description for the deal terms.
Corresponds to the JSON property description
1249 1250 1251 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1249 def description @description end |
#display_name ⇒ String
The name of the deal.
Corresponds to the JSON property displayName
1254 1255 1256 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1254 def display_name @display_name end |
#external_deal_id ⇒ String
Output only. The external deal ID assigned to this deal once the deal is
finalized. This is the deal ID that shows up in serving/reporting etc.
Corresponds to the JSON property externalDealId
1260 1261 1262 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1260 def external_deal_id @external_deal_id end |
#is_setup_complete ⇒ Boolean Also known as: is_setup_complete?
Output only. True, if the buyside inventory setup is complete for this deal.
Corresponds to the JSON property isSetupComplete
1265 1266 1267 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1265 def is_setup_complete @is_setup_complete end |
#programmatic_creative_source ⇒ String
Output only. Specifies the creative source for programmatic deals. PUBLISHER
means creative is provided by seller and ADVERTISER means creative is provided
by buyer.
Corresponds to the JSON property programmaticCreativeSource
1273 1274 1275 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1273 def programmatic_creative_source @programmatic_creative_source end |
#proposal_id ⇒ String
Output only. ID of the proposal that this deal is part of.
Corresponds to the JSON property proposalId
1278 1279 1280 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1278 def proposal_id @proposal_id end |
#seller_contacts ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ContactInformation>
Output only. Seller contact information for the deal.
Corresponds to the JSON property sellerContacts
1283 1284 1285 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1283 def seller_contacts @seller_contacts end |
#syndication_product ⇒ String
The syndication product associated with the deal. Note: This field may be set
only when creating the resource. Modifying this field while updating the
resource will result in an error.
Corresponds to the JSON property syndicationProduct
1290 1291 1292 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1290 def @syndication_product end |
#targeting ⇒ Google::Apis::Adexchangebuyer2V2beta1::MarketplaceTargeting
Targeting represents different criteria that can be used by advertisers to
target ad inventory. For example, they can choose to target ad requests only
if the user is in the US. Multiple types of targeting are always applied as a
logical AND, unless noted otherwise.
Corresponds to the JSON property targeting
1298 1299 1300 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1298 def targeting @targeting end |
#targeting_criterion ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::TargetingCriteria>
The shared targeting visible to buyers and sellers. Each shared targeting
entity is AND'd together.
Corresponds to the JSON property targetingCriterion
1304 1305 1306 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1304 def targeting_criterion @targeting_criterion end |
#update_time ⇒ String
Output only. The time when the deal was last updated.
Corresponds to the JSON property updateTime
1309 1310 1311 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1309 def update_time @update_time end |
#web_property_code ⇒ String
The web property code for the seller copied over from the product.
Corresponds to the JSON property webPropertyCode
1314 1315 1316 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1314 def web_property_code @web_property_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1321 def update!(**args) @available_end_time = args[:available_end_time] if args.key?(:available_end_time) @available_start_time = args[:available_start_time] if args.key?(:available_start_time) @buyer_private_data = args[:buyer_private_data] if args.key?(:buyer_private_data) @create_product_id = args[:create_product_id] if args.key?(:create_product_id) @create_product_revision = args[:create_product_revision] if args.key?(:create_product_revision) @create_time = args[:create_time] if args.key?(:create_time) @creative_pre_approval_policy = args[:creative_pre_approval_policy] if args.key?(:creative_pre_approval_policy) @creative_restrictions = args[:creative_restrictions] if args.key?(:creative_restrictions) @creative_safe_frame_compatibility = args[:creative_safe_frame_compatibility] if args.key?(:creative_safe_frame_compatibility) @deal_id = args[:deal_id] if args.key?(:deal_id) @deal_serving_metadata = args[:deal_serving_metadata] if args.key?(:deal_serving_metadata) @deal_terms = args[:deal_terms] if args.key?(:deal_terms) @delivery_control = args[:delivery_control] if args.key?(:delivery_control) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @external_deal_id = args[:external_deal_id] if args.key?(:external_deal_id) @is_setup_complete = args[:is_setup_complete] if args.key?(:is_setup_complete) @programmatic_creative_source = args[:programmatic_creative_source] if args.key?(:programmatic_creative_source) @proposal_id = args[:proposal_id] if args.key?(:proposal_id) @seller_contacts = args[:seller_contacts] if args.key?(:seller_contacts) @syndication_product = args[:syndication_product] if args.key?(:syndication_product) @targeting = args[:targeting] if args.key?(:targeting) @targeting_criterion = args[:targeting_criterion] if args.key?(:targeting_criterion) @update_time = args[:update_time] if args.key?(:update_time) @web_property_code = args[:web_property_code] if args.key?(:web_property_code) end |