Class: Google::Apis::Adexchangebuyer2V2beta1::FilterSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Overview

A set of filters that is applied to a request for data. Within a filter set, an AND operation is performed across the filters represented by each field. An OR operation is performed across the filters represented by the multiple values of a repeated field, for example, "format=VIDEO AND deal_id=12 AND ( seller_network_id=34 OR seller_network_id=56)".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FilterSet

Returns a new instance of FilterSet.



1665
1666
1667
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#absolute_date_rangeGoogle::Apis::Adexchangebuyer2V2beta1::AbsoluteDateRange

An absolute date range, specified by its start date and end date. The supported range of dates begins 30 days before today and ends today. Validity checked upon filter set creation. If a filter set with an absolute date range is run at a later date more than 30 days after start_date, it will fail. Corresponds to the JSON property absoluteDateRange



1570
1571
1572
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1570

def absolute_date_range
  @absolute_date_range
end

#breakdown_dimensionsArray<String>

The set of dimensions along which to break down the response; may be empty. If multiple dimensions are requested, the breakdown is along the Cartesian product of the requested dimensions. Corresponds to the JSON property breakdownDimensions

Returns:

  • (Array<String>)


1577
1578
1579
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1577

def breakdown_dimensions
  @breakdown_dimensions
end

#creative_idString

The ID of the creative on which to filter; optional. This field may be set only for a filter set that accesses account-level troubleshooting data, for example, one whose name matches the bidders/*/accounts/*/filterSets/* pattern. Corresponds to the JSON property creativeId

Returns:

  • (String)


1585
1586
1587
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1585

def creative_id
  @creative_id
end

#deal_idFixnum

The ID of the deal on which to filter; optional. This field may be set only for a filter set that accesses account-level troubleshooting data, for example, one whose name matches the bidders/*/accounts/*/filterSets/* pattern. Corresponds to the JSON property dealId

Returns:

  • (Fixnum)


1592
1593
1594
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1592

def deal_id
  @deal_id
end

#environmentString

The environment on which to filter; optional. Corresponds to the JSON property environment

Returns:

  • (String)


1597
1598
1599
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1597

def environment
  @environment
end

#formatString

Creative format bidded on or allowed to bid on, can be empty. Corresponds to the JSON property format

Returns:

  • (String)


1602
1603
1604
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1602

def format
  @format
end

#formatsArray<String>

Creative formats bidded on or allowed to bid on, can be empty. Although this field is a list, it can only be populated with a single item. A HTTP 400 bad request error will be returned in the response if you specify multiple items. Corresponds to the JSON property formats

Returns:

  • (Array<String>)


1609
1610
1611
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1609

def formats
  @formats
end

#nameString

A user-defined name of the filter set. Filter set names must be unique globally and match one of the patterns: - bidders/*/filterSets/* (for accessing bidder-level troubleshooting data) - bidders/*/accounts/*/ filterSets/* (for accessing account-level troubleshooting data) This field is required in create operations. Corresponds to the JSON property name

Returns:

  • (String)


1618
1619
1620
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1618

def name
  @name
end

#platformsArray<String>

The list of platforms on which to filter; may be empty. The filters represented by multiple platforms are ORed together (for example, if non-empty, results must match any one of the platforms). Corresponds to the JSON property platforms

Returns:

  • (Array<String>)


1625
1626
1627
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1625

def platforms
  @platforms
end

#publisher_identifiersArray<String>

For Open Bidding partners only. The list of publisher identifiers on which to filter; may be empty. The filters represented by multiple publisher identifiers are ORed together. Corresponds to the JSON property publisherIdentifiers

Returns:

  • (Array<String>)


1632
1633
1634
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1632

def publisher_identifiers
  @publisher_identifiers
end

#realtime_time_rangeGoogle::Apis::Adexchangebuyer2V2beta1::RealtimeTimeRange

An open-ended realtime time range specified by the start timestamp. For filter sets that specify a realtime time range RTB metrics continue to be aggregated throughout the lifetime of the filter set. Corresponds to the JSON property realtimeTimeRange



1639
1640
1641
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1639

def realtime_time_range
  @realtime_time_range
end

#relative_date_rangeGoogle::Apis::Adexchangebuyer2V2beta1::RelativeDateRange

A relative date range, specified by an offset and a duration. The supported range of dates begins 30 days before today and ends today, for example, the limits for these values are: offset_days >= 0 duration_days >= 1 offset_days + duration_days <= 30 Corresponds to the JSON property relativeDateRange



1647
1648
1649
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1647

def relative_date_range
  @relative_date_range
end

#seller_network_idsArray<Fixnum>

For Authorized Buyers only. The list of IDs of the seller (publisher) networks on which to filter; may be empty. The filters represented by multiple seller network IDs are ORed together (for example, if non-empty, results must match any one of the publisher networks). See seller-network-ids file for the set of existing seller network IDs. Corresponds to the JSON property sellerNetworkIds

Returns:

  • (Array<Fixnum>)


1657
1658
1659
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1657

def seller_network_ids
  @seller_network_ids
end

#time_series_granularityString

The granularity of time intervals if a time series breakdown is preferred; optional. Corresponds to the JSON property timeSeriesGranularity

Returns:

  • (String)


1663
1664
1665
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1663

def time_series_granularity
  @time_series_granularity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1670

def update!(**args)
  @absolute_date_range = args[:absolute_date_range] if args.key?(:absolute_date_range)
  @breakdown_dimensions = args[:breakdown_dimensions] if args.key?(:breakdown_dimensions)
  @creative_id = args[:creative_id] if args.key?(:creative_id)
  @deal_id = args[:deal_id] if args.key?(:deal_id)
  @environment = args[:environment] if args.key?(:environment)
  @format = args[:format] if args.key?(:format)
  @formats = args[:formats] if args.key?(:formats)
  @name = args[:name] if args.key?(:name)
  @platforms = args[:platforms] if args.key?(:platforms)
  @publisher_identifiers = args[:publisher_identifiers] if args.key?(:publisher_identifiers)
  @realtime_time_range = args[:realtime_time_range] if args.key?(:realtime_time_range)
  @relative_date_range = args[:relative_date_range] if args.key?(:relative_date_range)
  @seller_network_ids = args[:seller_network_ids] if args.key?(:seller_network_ids)
  @time_series_granularity = args[:time_series_granularity] if args.key?(:time_series_granularity)
end