Class: Google::Apis::Adexchangebuyer2V2beta1::FilteredBidDetailRow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Overview

The number of filtered bids with the specified dimension values, among those filtered due to the requested filtering reason (for example, creative status), that have the specified detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FilteredBidDetailRow

Returns a new instance of FilteredBidDetailRow.



1756
1757
1758
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1756

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bid_countGoogle::Apis::Adexchangebuyer2V2beta1::MetricValue

A metric value, with an expected value and a variance; represents a count that may be either exact or estimated (for example, when sampled). Corresponds to the JSON property bidCount



1732
1733
1734
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1732

def bid_count
  @bid_count
end

#detailString

The ID of the detail, can be numeric or text. The associated value can be looked up in the dictionary file corresponding to the DetailType in the response message. Corresponds to the JSON property detail

Returns:

  • (String)


1739
1740
1741
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1739

def detail
  @detail
end

#detail_idFixnum

Note: this field will be deprecated, use "detail" field instead. When "detail" field represents an integer value, this field is populated as the same integer value "detail" field represents, otherwise this field will be 0. The ID of the detail. The associated value can be looked up in the dictionary file corresponding to the DetailType in the response message. Corresponds to the JSON property detailId

Returns:

  • (Fixnum)


1748
1749
1750
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1748

def detail_id
  @detail_id
end

#row_dimensionsGoogle::Apis::Adexchangebuyer2V2beta1::RowDimensions

A response may include multiple rows, breaking down along various dimensions. Encapsulates the values of all dimensions for a given row. Corresponds to the JSON property rowDimensions



1754
1755
1756
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1754

def row_dimensions
  @row_dimensions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1761
1762
1763
1764
1765
1766
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1761

def update!(**args)
  @bid_count = args[:bid_count] if args.key?(:bid_count)
  @detail = args[:detail] if args.key?(:detail)
  @detail_id = args[:detail_id] if args.key?(:detail_id)
  @row_dimensions = args[:row_dimensions] if args.key?(:row_dimensions)
end