Class: Google::Apis::Adexchangebuyer2V2beta1::FirstPartyMobileApplicationTargeting
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::FirstPartyMobileApplicationTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
Represents a list of targeted and excluded mobile application IDs that publishers own. Mobile application IDs are from App Store and Google Play Store. Android App ID, for example, com.google.android.apps.maps, can be found in Google Play Store URL. iOS App ID (which is a number) can be found at the end of iTunes store URL. First party mobile applications is either included or excluded.
Instance Attribute Summary collapse
-
#excluded_app_ids ⇒ Array<String>
A list of application IDs to be excluded.
-
#targeted_app_ids ⇒ Array<String>
A list of application IDs to be included.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirstPartyMobileApplicationTargeting
constructor
A new instance of FirstPartyMobileApplicationTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirstPartyMobileApplicationTargeting
Returns a new instance of FirstPartyMobileApplicationTargeting.
1788 1789 1790 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1788 def initialize(**args) update!(**args) end |
Instance Attribute Details
#excluded_app_ids ⇒ Array<String>
A list of application IDs to be excluded.
Corresponds to the JSON property excludedAppIds
1781 1782 1783 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1781 def excluded_app_ids @excluded_app_ids end |
#targeted_app_ids ⇒ Array<String>
A list of application IDs to be included.
Corresponds to the JSON property targetedAppIds
1786 1787 1788 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1786 def targeted_app_ids @targeted_app_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1793 1794 1795 1796 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1793 def update!(**args) @excluded_app_ids = args[:excluded_app_ids] if args.key?(:excluded_app_ids) @targeted_app_ids = args[:targeted_app_ids] if args.key?(:targeted_app_ids) end |