Class: Google::Apis::Adexchangebuyer2V2beta1::GuaranteedFixedPriceTerms
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::GuaranteedFixedPriceTerms
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
Terms for Programmatic Guaranteed Deals.
Instance Attribute Summary collapse
-
#fixed_prices ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::PricePerBuyer>
Fixed price for the specified buyer.
-
#guaranteed_impressions ⇒ Fixnum
Guaranteed impressions as a percentage.
-
#guaranteed_looks ⇒ Fixnum
Count of guaranteed looks.
-
#impression_cap ⇒ Fixnum
The lifetime impression cap for CPM sponsorship deals.
-
#minimum_daily_looks ⇒ Fixnum
Daily minimum looks for CPD deal types.
-
#percent_share_of_voice ⇒ Fixnum
For sponsorship deals, this is the percentage of the seller's eligible impressions that the deal will serve until the cap is reached.
-
#reservation_type ⇒ String
The reservation type for a Programmatic Guaranteed deal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GuaranteedFixedPriceTerms
constructor
A new instance of GuaranteedFixedPriceTerms.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GuaranteedFixedPriceTerms
Returns a new instance of GuaranteedFixedPriceTerms.
1879 1880 1881 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1879 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fixed_prices ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::PricePerBuyer>
Fixed price for the specified buyer.
Corresponds to the JSON property fixedPrices
1840 1841 1842 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1840 def fixed_prices @fixed_prices end |
#guaranteed_impressions ⇒ Fixnum
Guaranteed impressions as a percentage. This is the percentage of guaranteed
looks that the buyer is guaranteeing to buy.
Corresponds to the JSON property guaranteedImpressions
1846 1847 1848 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1846 def guaranteed_impressions @guaranteed_impressions end |
#guaranteed_looks ⇒ Fixnum
Count of guaranteed looks. Required for deal, optional for product. For CPD
deals, buyer changes to guaranteed_looks will be ignored.
Corresponds to the JSON property guaranteedLooks
1852 1853 1854 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1852 def guaranteed_looks @guaranteed_looks end |
#impression_cap ⇒ Fixnum
The lifetime impression cap for CPM sponsorship deals. The deal will stop
serving when the cap is reached.
Corresponds to the JSON property impressionCap
1858 1859 1860 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1858 def impression_cap @impression_cap end |
#minimum_daily_looks ⇒ Fixnum
Daily minimum looks for CPD deal types. For CPD deals, buyer should negotiate
on this field instead of guaranteed_looks.
Corresponds to the JSON property minimumDailyLooks
1864 1865 1866 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1864 def minimum_daily_looks @minimum_daily_looks end |
#percent_share_of_voice ⇒ Fixnum
For sponsorship deals, this is the percentage of the seller's eligible
impressions that the deal will serve until the cap is reached.
Corresponds to the JSON property percentShareOfVoice
1870 1871 1872 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1870 def percent_share_of_voice @percent_share_of_voice end |
#reservation_type ⇒ String
The reservation type for a Programmatic Guaranteed deal. This indicates
whether the number of impressions is fixed, or a percent of available
impressions. If not specified, the default reservation type is STANDARD.
Corresponds to the JSON property reservationType
1877 1878 1879 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1877 def reservation_type @reservation_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1884 def update!(**args) @fixed_prices = args[:fixed_prices] if args.key?(:fixed_prices) @guaranteed_impressions = args[:guaranteed_impressions] if args.key?(:guaranteed_impressions) @guaranteed_looks = args[:guaranteed_looks] if args.key?(:guaranteed_looks) @impression_cap = args[:impression_cap] if args.key?(:impression_cap) @minimum_daily_looks = args[:minimum_daily_looks] if args.key?(:minimum_daily_looks) @percent_share_of_voice = args[:percent_share_of_voice] if args.key?(:percent_share_of_voice) @reservation_type = args[:reservation_type] if args.key?(:reservation_type) end |