Class: Google::Apis::Adexchangebuyer2V2beta1::ImpressionMetricsRow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Overview

The set of metrics that are measured in numbers of impressions, representing how many impressions with the specified dimension values were considered eligible at each stage of the bidding funnel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImpressionMetricsRow

Returns a new instance of ImpressionMetricsRow.



2000
2001
2002
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_impressionsGoogle::Apis::Adexchangebuyer2V2beta1::MetricValue

A metric value, with an expected value and a variance; represents a count that may be either exact or estimated (for example, when sampled). Corresponds to the JSON property availableImpressions



1968
1969
1970
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1968

def available_impressions
  @available_impressions
end

#bid_requestsGoogle::Apis::Adexchangebuyer2V2beta1::MetricValue

A metric value, with an expected value and a variance; represents a count that may be either exact or estimated (for example, when sampled). Corresponds to the JSON property bidRequests



1974
1975
1976
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1974

def bid_requests
  @bid_requests
end

#inventory_matchesGoogle::Apis::Adexchangebuyer2V2beta1::MetricValue

A metric value, with an expected value and a variance; represents a count that may be either exact or estimated (for example, when sampled). Corresponds to the JSON property inventoryMatches



1980
1981
1982
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1980

def inventory_matches
  @inventory_matches
end

#responses_with_bidsGoogle::Apis::Adexchangebuyer2V2beta1::MetricValue

A metric value, with an expected value and a variance; represents a count that may be either exact or estimated (for example, when sampled). Corresponds to the JSON property responsesWithBids



1986
1987
1988
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1986

def responses_with_bids
  @responses_with_bids
end

#row_dimensionsGoogle::Apis::Adexchangebuyer2V2beta1::RowDimensions

A response may include multiple rows, breaking down along various dimensions. Encapsulates the values of all dimensions for a given row. Corresponds to the JSON property rowDimensions



1992
1993
1994
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1992

def row_dimensions
  @row_dimensions
end

#successful_responsesGoogle::Apis::Adexchangebuyer2V2beta1::MetricValue

A metric value, with an expected value and a variance; represents a count that may be either exact or estimated (for example, when sampled). Corresponds to the JSON property successfulResponses



1998
1999
2000
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 1998

def successful_responses
  @successful_responses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2005
2006
2007
2008
2009
2010
2011
2012
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2005

def update!(**args)
  @available_impressions = args[:available_impressions] if args.key?(:available_impressions)
  @bid_requests = args[:bid_requests] if args.key?(:bid_requests)
  @inventory_matches = args[:inventory_matches] if args.key?(:inventory_matches)
  @responses_with_bids = args[:responses_with_bids] if args.key?(:responses_with_bids)
  @row_dimensions = args[:row_dimensions] if args.key?(:row_dimensions)
  @successful_responses = args[:successful_responses] if args.key?(:successful_responses)
end