Class: Google::Apis::Adexchangebuyer2V2beta1::ListBidResponsesWithoutBidsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::ListBidResponsesWithoutBidsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
Response message for listing all reasons that bid responses were considered to have no applicable bids.
Instance Attribute Summary collapse
-
#bid_response_without_bids_status_rows ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::BidResponseWithoutBidsStatusRow>
List of rows, with counts of bid responses without bids aggregated by status.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBidResponsesWithoutBidsResponse
constructor
A new instance of ListBidResponsesWithoutBidsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBidResponsesWithoutBidsResponse
Returns a new instance of ListBidResponsesWithoutBidsResponse.
2115 2116 2117 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bid_response_without_bids_status_rows ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::BidResponseWithoutBidsStatusRow>
List of rows, with counts of bid responses without bids aggregated by status.
Corresponds to the JSON property bidResponseWithoutBidsStatusRows
2106 2107 2108 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2106 def bid_response_without_bids_status_rows @bid_response_without_bids_status_rows end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListBidResponsesWithoutBidsRequest.pageToken field in the subsequent call to
the bidResponsesWithoutBids.list method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
2113 2114 2115 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2113 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2120 2121 2122 2123 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2120 def update!(**args) @bid_response_without_bids_status_rows = args[:bid_response_without_bids_status_rows] if args.key?(:bid_response_without_bids_status_rows) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |