Class: Google::Apis::Adexchangebuyer2V2beta1::ListClientUserInvitationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListClientUserInvitationsResponse

Returns a new instance of ListClientUserInvitationsResponse.



2142
2143
2144
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#invitationsArray<Google::Apis::Adexchangebuyer2V2beta1::ClientUserInvitation>

The returned list of client users. Corresponds to the JSON property invitations



2133
2134
2135
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2133

def invitations
  @invitations
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the ListClientUserInvitationsRequest.pageToken field in the subsequent call to the clients.invitations.list method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2140
2141
2142
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2140

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2147
2148
2149
2150
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2147

def update!(**args)
  @invitations = args[:invitations] if args.key?(:invitations)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end