Class: Google::Apis::Adexchangebuyer2V2beta1::ListClientsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::ListClientsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Instance Attribute Summary collapse
-
#clients ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::Client>
The returned list of clients.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListClientsResponse
constructor
A new instance of ListClientsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListClientsResponse
Returns a new instance of ListClientsResponse.
2196 2197 2198 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2196 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clients ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::Client>
The returned list of clients.
Corresponds to the JSON property clients
2187 2188 2189 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2187 def clients @clients end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListClientsRequest.pageToken field in the subsequent call to the accounts.
clients.list method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
2194 2195 2196 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2194 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2201 2202 2203 2204 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2201 def update!(**args) @clients = args[:clients] if args.key?(:clients) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |