Class: Google::Apis::Adexchangebuyer2V2beta1::ListCreativeStatusBreakdownByDetailResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Overview

Response message for listing all details associated with a given filtered bid reason.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCreativeStatusBreakdownByDetailResponse

Returns a new instance of ListCreativeStatusBreakdownByDetailResponse.



2261
2262
2263
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detail_typeString

The type of detail that the detail IDs represent. Corresponds to the JSON property detailType

Returns:

  • (String)


2245
2246
2247
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2245

def detail_type
  @detail_type
end

#filtered_bid_detail_rowsArray<Google::Apis::Adexchangebuyer2V2beta1::FilteredBidDetailRow>

List of rows, with counts of bids with a given creative status aggregated by detail. Corresponds to the JSON property filteredBidDetailRows



2251
2252
2253
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2251

def filtered_bid_detail_rows
  @filtered_bid_detail_rows
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the ListCreativeStatusBreakdownByDetailRequest.pageToken field in the subsequent call to the filteredBids.details.list method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2259
2260
2261
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2259

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2266
2267
2268
2269
2270
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2266

def update!(**args)
  @detail_type = args[:detail_type] if args.key?(:detail_type)
  @filtered_bid_detail_rows = args[:filtered_bid_detail_rows] if args.key?(:filtered_bid_detail_rows)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end