Class: Google::Apis::Adexchangebuyer2V2beta1::ListNonBillableWinningBidsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::ListNonBillableWinningBidsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
Response message for listing all reasons for which a buyer was not billed for a winning bid.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#non_billable_winning_bid_status_rows ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::NonBillableWinningBidStatusRow>
List of rows, with counts of bids not billed aggregated by reason.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListNonBillableWinningBidsResponse
constructor
A new instance of ListNonBillableWinningBidsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListNonBillableWinningBidsResponse
Returns a new instance of ListNonBillableWinningBidsResponse.
2485 2486 2487 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListNonBillableWinningBidsRequest.pageToken field in the subsequent call to
the nonBillableWinningBids.list method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
2478 2479 2480 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2478 def next_page_token @next_page_token end |
#non_billable_winning_bid_status_rows ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::NonBillableWinningBidStatusRow>
List of rows, with counts of bids not billed aggregated by reason.
Corresponds to the JSON property nonBillableWinningBidStatusRows
2483 2484 2485 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2483 def non_billable_winning_bid_status_rows @non_billable_winning_bid_status_rows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2490 2491 2492 2493 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2490 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @non_billable_winning_bid_status_rows = args[:non_billable_winning_bid_status_rows] if args.key?(:non_billable_winning_bid_status_rows) end |