Class: Google::Apis::Adexchangebuyer2V2beta1::MarketplaceTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Overview

Targeting represents different criteria that can be used by advertisers to target ad inventory. For example, they can choose to target ad requests only if the user is in the US. Multiple types of targeting are always applied as a logical AND, unless noted otherwise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MarketplaceTargeting

Returns a new instance of MarketplaceTargeting.



2630
2631
2632
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#geo_targetingGoogle::Apis::Adexchangebuyer2V2beta1::CriteriaTargeting

Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs. Corresponds to the JSON property geoTargeting



2603
2604
2605
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2603

def geo_targeting
  @geo_targeting
end

#inventory_size_targetingGoogle::Apis::Adexchangebuyer2V2beta1::InventorySizeTargeting

Represents the size of an ad unit that can be targeted on an ad request. It only applies to Private Auction, AdX Preferred Deals and Auction Packages. This targeting does not apply to Programmatic Guaranteed and Preferred Deals in Ad Manager. Corresponds to the JSON property inventorySizeTargeting



2611
2612
2613
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2611

def inventory_size_targeting
  @inventory_size_targeting
end

#placement_targetingGoogle::Apis::Adexchangebuyer2V2beta1::PlacementTargeting

Represents targeting about where the ads can appear, for example, certain sites or mobile applications. Different placement targeting types will be logically OR'ed. Corresponds to the JSON property placementTargeting



2618
2619
2620
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2618

def placement_targeting
  @placement_targeting
end

#technology_targetingGoogle::Apis::Adexchangebuyer2V2beta1::TechnologyTargeting

Represents targeting about various types of technology. Corresponds to the JSON property technologyTargeting



2623
2624
2625
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2623

def technology_targeting
  @technology_targeting
end

#video_targetingGoogle::Apis::Adexchangebuyer2V2beta1::VideoTargeting

Represents targeting information about video. Corresponds to the JSON property videoTargeting



2628
2629
2630
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2628

def video_targeting
  @video_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2635
2636
2637
2638
2639
2640
2641
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2635

def update!(**args)
  @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting)
  @inventory_size_targeting = args[:inventory_size_targeting] if args.key?(:inventory_size_targeting)
  @placement_targeting = args[:placement_targeting] if args.key?(:placement_targeting)
  @technology_targeting = args[:technology_targeting] if args.key?(:technology_targeting)
  @video_targeting = args[:video_targeting] if args.key?(:video_targeting)
end