Class: Google::Apis::Adexchangebuyer2V2beta1::Money
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::Money
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
Represents an amount of money with its currency type.
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
-
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount.
-
#units ⇒ Fixnum
The whole units of the amount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Money
constructor
A new instance of Money.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Money
Returns a new instance of Money.
2723 2724 2725 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2723 def initialize(**args) update!(**args) end |
Instance Attribute Details
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
Corresponds to the JSON property currencyCode
2706 2707 2708 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2706 def currency_code @currency_code end |
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount. The value must be between -999,999,
999 and +999,999,999 inclusive. If units is positive, nanos must be
positive or zero. If units is zero, nanos can be positive, zero, or
negative. If units is negative, nanos must be negative or zero. For
example $-1.75 is represented as units=-1 and nanos=-750,000,000.
Corresponds to the JSON property nanos
2715 2716 2717 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2715 def nanos @nanos end |
#units ⇒ Fixnum
The whole units of the amount. For example if currencyCode is "USD", then
1 unit is one US dollar.
Corresponds to the JSON property units
2721 2722 2723 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2721 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2728 2729 2730 2731 2732 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2728 def update!(**args) @currency_code = args[:currency_code] if args.key?(:currency_code) @nanos = args[:nanos] if args.key?(:nanos) @units = args[:units] if args.key?(:units) end |