Class: Google::Apis::Adexchangebuyer2V2beta1::NonBillableWinningBidStatusRow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Overview

The number of winning bids with the specified dimension values for which the buyer was not billed, as described by the specified status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NonBillableWinningBidStatusRow

Returns a new instance of NonBillableWinningBidStatusRow.



2851
2852
2853
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bid_countGoogle::Apis::Adexchangebuyer2V2beta1::MetricValue

A metric value, with an expected value and a variance; represents a count that may be either exact or estimated (for example, when sampled). Corresponds to the JSON property bidCount



2838
2839
2840
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2838

def bid_count
  @bid_count
end

#row_dimensionsGoogle::Apis::Adexchangebuyer2V2beta1::RowDimensions

A response may include multiple rows, breaking down along various dimensions. Encapsulates the values of all dimensions for a given row. Corresponds to the JSON property rowDimensions



2844
2845
2846
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2844

def row_dimensions
  @row_dimensions
end

#statusString

The status specifying why the winning bids were not billed. Corresponds to the JSON property status

Returns:

  • (String)


2849
2850
2851
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2849

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2856
2857
2858
2859
2860
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2856

def update!(**args)
  @bid_count = args[:bid_count] if args.key?(:bid_count)
  @row_dimensions = args[:row_dimensions] if args.key?(:row_dimensions)
  @status = args[:status] if args.key?(:status)
end