Class: Google::Apis::Adexchangebuyer2V2beta1::Note
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::Note
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
A proposal may be associated to several notes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#creator_role ⇒ String
Output only.
-
#note ⇒ String
The actual note to attach.
-
#note_id ⇒ String
Output only.
-
#proposal_revision ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Note
constructor
A new instance of Note.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Note
Returns a new instance of Note.
2941 2942 2943 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp for when this note was created.
Corresponds to the JSON property createTime
2917 2918 2919 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2917 def create_time @create_time end |
#creator_role ⇒ String
Output only. The role of the person (buyer/seller) creating the note.
Corresponds to the JSON property creatorRole
2922 2923 2924 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2922 def creator_role @creator_role end |
#note ⇒ String
The actual note to attach. (max-length: 1024 unicode code units) Note: This
field may be set only when creating the resource. Modifying this field while
updating the resource will result in an error.
Corresponds to the JSON property note
2929 2930 2931 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2929 def note @note end |
#note_id ⇒ String
Output only. The unique ID for the note.
Corresponds to the JSON property noteId
2934 2935 2936 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2934 def note_id @note_id end |
#proposal_revision ⇒ Fixnum
Output only. The revision number of the proposal when the note is created.
Corresponds to the JSON property proposalRevision
2939 2940 2941 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2939 def proposal_revision @proposal_revision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2946 2947 2948 2949 2950 2951 2952 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2946 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @creator_role = args[:creator_role] if args.key?(:creator_role) @note = args[:note] if args.key?(:note) @note_id = args[:note_id] if args.key?(:note_id) @proposal_revision = args[:proposal_revision] if args.key?(:proposal_revision) end |