Class: Google::Apis::Adexchangebuyer2V2beta1::Price

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Overview

Represents a price and a pricing type for a product / deal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Price

Returns a new instance of Price.



3091
3092
3093
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amountGoogle::Apis::Adexchangebuyer2V2beta1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property amount



3084
3085
3086
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3084

def amount
  @amount
end

#pricing_typeString

The pricing type for the deal/product. (default: CPM) Corresponds to the JSON property pricingType

Returns:

  • (String)


3089
3090
3091
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3089

def pricing_type
  @pricing_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3096
3097
3098
3099
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3096

def update!(**args)
  @amount = args[:amount] if args.key?(:amount)
  @pricing_type = args[:pricing_type] if args.key?(:pricing_type)
end