Class: Google::Apis::Adexchangebuyer2V2beta1::PublisherProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Overview

Represents a publisher profile (https://support.google.com/admanager/answer/ 6035806) in Marketplace. All fields are read only. All string fields are free- form text entered by the publisher unless noted otherwise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublisherProfile

Returns a new instance of PublisherProfile.



3532
3533
3534
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audience_descriptionString

Description on the publisher's audience. Corresponds to the JSON property audienceDescription

Returns:

  • (String)


3431
3432
3433
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3431

def audience_description
  @audience_description
end

#buyer_pitch_statementString

Statement explaining what's unique about publisher's business, and why buyers should partner with the publisher. Corresponds to the JSON property buyerPitchStatement

Returns:

  • (String)


3437
3438
3439
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3437

def buyer_pitch_statement
  @buyer_pitch_statement
end

#direct_deals_contactString

Contact information for direct reservation deals. This is free text entered by the publisher and may include information like names, phone numbers and email addresses. Corresponds to the JSON property directDealsContact

Returns:

  • (String)


3444
3445
3446
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3444

def direct_deals_contact
  @direct_deals_contact
end

#display_nameString

Name of the publisher profile. Corresponds to the JSON property displayName

Returns:

  • (String)


3449
3450
3451
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3449

def display_name
  @display_name
end

#domainsArray<String>

The list of domains represented in this publisher profile. Empty if this is a parent profile. These are top private domains, meaning that these will not contain a string like "photos.google.co.uk/123", but will instead contain " google.co.uk". Corresponds to the JSON property domains

Returns:

  • (Array<String>)


3457
3458
3459
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3457

def domains
  @domains
end

#google_plus_urlString

URL to publisher's Google+ page. Corresponds to the JSON property googlePlusUrl

Returns:

  • (String)


3462
3463
3464
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3462

def google_plus_url
  @google_plus_url
end

#is_parentBoolean Also known as: is_parent?

Indicates if this profile is the parent profile of the seller. A parent profile represents all the inventory from the seller, as opposed to child profile that is created to brand a portion of inventory. One seller should have only one parent publisher profile, and can have multiple child profiles. Publisher profiles for the same seller will have same value of field google. ads.adexchange.buyer.v2beta1.PublisherProfile.seller. See https://support. google.com/admanager/answer/6035806 for details. Corresponds to the JSON property isParent

Returns:

  • (Boolean)


3473
3474
3475
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3473

def is_parent
  @is_parent
end

#logo_urlString

A Google public URL to the logo for this publisher profile. The logo is stored as a PNG, JPG, or GIF image. Corresponds to the JSON property logoUrl

Returns:

  • (String)


3480
3481
3482
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3480

def logo_url
  @logo_url
end

#media_kit_urlString

URL to additional marketing and sales materials. Corresponds to the JSON property mediaKitUrl

Returns:

  • (String)


3485
3486
3487
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3485

def media_kit_url
  @media_kit_url
end

#mobile_appsArray<Google::Apis::Adexchangebuyer2V2beta1::PublisherProfileMobileApplication>

The list of apps represented in this publisher profile. Empty if this is a parent profile. Corresponds to the JSON property mobileApps



3491
3492
3493
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3491

def mobile_apps
  @mobile_apps
end

#overviewString

Overview of the publisher. Corresponds to the JSON property overview

Returns:

  • (String)


3496
3497
3498
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3496

def overview
  @overview
end

#programmatic_deals_contactString

Contact information for programmatic deals. This is free text entered by the publisher and may include information like names, phone numbers and email addresses. Corresponds to the JSON property programmaticDealsContact

Returns:

  • (String)


3503
3504
3505
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3503

def programmatic_deals_contact
  @programmatic_deals_contact
end

#publisher_profile_idString

Unique ID for publisher profile. Corresponds to the JSON property publisherProfileId

Returns:

  • (String)


3508
3509
3510
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3508

def publisher_profile_id
  @publisher_profile_id
end

#rate_card_info_urlString

URL to a publisher rate card. Corresponds to the JSON property rateCardInfoUrl

Returns:

  • (String)


3513
3514
3515
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3513

def rate_card_info_url
  @rate_card_info_url
end

#sample_page_urlString

URL to a sample content page. Corresponds to the JSON property samplePageUrl

Returns:

  • (String)


3518
3519
3520
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3518

def sample_page_url
  @sample_page_url
end

#sellerGoogle::Apis::Adexchangebuyer2V2beta1::Seller

Represents a seller of inventory. Each seller is identified by a unique Ad Manager account ID. Corresponds to the JSON property seller



3524
3525
3526
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3524

def seller
  @seller
end

#top_headlinesArray<String>

Up to three key metrics and rankings. Max 100 characters each. For example "#1 Mobile News Site for 20 Straight Months". Corresponds to the JSON property topHeadlines

Returns:

  • (Array<String>)


3530
3531
3532
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3530

def top_headlines
  @top_headlines
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3537
3538
3539
3540
3541
3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3537

def update!(**args)
  @audience_description = args[:audience_description] if args.key?(:audience_description)
  @buyer_pitch_statement = args[:buyer_pitch_statement] if args.key?(:buyer_pitch_statement)
  @direct_deals_contact = args[:direct_deals_contact] if args.key?(:direct_deals_contact)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domains = args[:domains] if args.key?(:domains)
  @google_plus_url = args[:google_plus_url] if args.key?(:google_plus_url)
  @is_parent = args[:is_parent] if args.key?(:is_parent)
  @logo_url = args[:logo_url] if args.key?(:logo_url)
  @media_kit_url = args[:media_kit_url] if args.key?(:media_kit_url)
  @mobile_apps = args[:mobile_apps] if args.key?(:mobile_apps)
  @overview = args[:overview] if args.key?(:overview)
  @programmatic_deals_contact = args[:programmatic_deals_contact] if args.key?(:programmatic_deals_contact)
  @publisher_profile_id = args[:publisher_profile_id] if args.key?(:publisher_profile_id)
  @rate_card_info_url = args[:rate_card_info_url] if args.key?(:rate_card_info_url)
  @sample_page_url = args[:sample_page_url] if args.key?(:sample_page_url)
  @seller = args[:seller] if args.key?(:seller)
  @top_headlines = args[:top_headlines] if args.key?(:top_headlines)
end