Class: Google::Apis::Adexchangebuyer2V2beta1::ServingRestriction
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::ServingRestriction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
Output only. A representation of the status of an ad in a specific context. A context here relates to where something ultimately serves (for example, a user or publisher geo, a platform, an HTTPS versus HTTP request, or the type of auction).
Instance Attribute Summary collapse
-
#contexts ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ServingContext>
The contexts for the restriction.
-
#disapproval ⇒ Google::Apis::Adexchangebuyer2V2beta1::Disapproval
Output only.
-
#disapproval_reasons ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::Disapproval>
Any disapprovals bound to this restriction.
-
#status ⇒ String
The status of the creative in this context (for example, it has been explicitly disapproved or is pending review).
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServingRestriction
constructor
A new instance of ServingRestriction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServingRestriction
Returns a new instance of ServingRestriction.
3846 3847 3848 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3846 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contexts ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ServingContext>
The contexts for the restriction.
Corresponds to the JSON property contexts
3826 3827 3828 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3826 def contexts @contexts end |
#disapproval ⇒ Google::Apis::Adexchangebuyer2V2beta1::Disapproval
Output only. The reason and details for a disapproval.
Corresponds to the JSON property disapproval
3831 3832 3833 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3831 def disapproval @disapproval end |
#disapproval_reasons ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::Disapproval>
Any disapprovals bound to this restriction. Only present if status=DISAPPROVED.
Can be used to filter the response of the creatives.list method. Deprecated;
use disapproval field instead.
Corresponds to the JSON property disapprovalReasons
3838 3839 3840 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3838 def disapproval_reasons @disapproval_reasons end |
#status ⇒ String
The status of the creative in this context (for example, it has been
explicitly disapproved or is pending review).
Corresponds to the JSON property status
3844 3845 3846 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3844 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3851 3852 3853 3854 3855 3856 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3851 def update!(**args) @contexts = args[:contexts] if args.key?(:contexts) @disapproval = args[:disapproval] if args.key?(:disapproval) @disapproval_reasons = args[:disapproval_reasons] if args.key?(:disapproval_reasons) @status = args[:status] if args.key?(:status) end |