Class: Google::Apis::Adexchangebuyer2V2beta1::Size

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Overview

Message depicting the size of the creative. The units of width and height depend on the type of the targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Size

Returns a new instance of Size.



3874
3875
3876
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#heightFixnum

The height of the creative. Corresponds to the JSON property height

Returns:

  • (Fixnum)


3867
3868
3869
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3867

def height
  @height
end

#widthFixnum

The width of the creative Corresponds to the JSON property width

Returns:

  • (Fixnum)


3872
3873
3874
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3872

def width
  @width
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3879
3880
3881
3882
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3879

def update!(**args)
  @height = args[:height] if args.key?(:height)
  @width = args[:width] if args.key?(:width)
end