Class: Google::Apis::Adexchangebuyer2V2beta1::VideoTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb

Overview

Represents targeting information about video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoTargeting

Returns a new instance of VideoTargeting.



4147
4148
4149
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 4147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excluded_position_typesArray<String>

A list of video positions to be excluded. Position types can either be included or excluded (XOR). Corresponds to the JSON property excludedPositionTypes

Returns:

  • (Array<String>)


4138
4139
4140
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 4138

def excluded_position_types
  @excluded_position_types
end

#targeted_position_typesArray<String>

A list of video positions to be included. When the included list is present, the excluded list must be empty. When the excluded list is present, the included list must be empty. Corresponds to the JSON property targetedPositionTypes

Returns:

  • (Array<String>)


4145
4146
4147
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 4145

def targeted_position_types
  @targeted_position_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4152
4153
4154
4155
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 4152

def update!(**args)
  @excluded_position_types = args[:excluded_position_types] if args.key?(:excluded_position_types)
  @targeted_position_types = args[:targeted_position_types] if args.key?(:targeted_position_types)
end