Class: Google::Apis::Adexchangebuyer2V2beta1::CompleteSetupRequest
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::CompleteSetupRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
Request message for indicating that the proposal's setup step is complete.
Instance Attribute Summary collapse
-
#external_deal_ids ⇒ Array<String>
The external deal ids of the deals to mark as setup completed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompleteSetupRequest
constructor
A new instance of CompleteSetupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompleteSetupRequest
Returns a new instance of CompleteSetupRequest.
594 595 596 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_deal_ids ⇒ Array<String>
The external deal ids of the deals to mark as setup completed. If empty, all
the deals in the proposal will be marked as setup completed.
Corresponds to the JSON property externalDealIds
592 593 594 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 592 def external_deal_ids @external_deal_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
599 600 601 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 599 def update!(**args) @external_deal_ids = args[:external_deal_ids] if args.key?(:external_deal_ids) end |