Class: Google::Apis::Adexchangebuyer2V2beta1::ListBidMetricsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::ListBidMetricsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
Response message for listing the metrics that are measured in number of bids.
Instance Attribute Summary collapse
-
#bid_metrics_rows ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::BidMetricsRow>
List of rows, each containing a set of bid metrics.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBidMetricsResponse
constructor
A new instance of ListBidMetricsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBidMetricsResponse
Returns a new instance of ListBidMetricsResponse.
2059 2060 2061 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bid_metrics_rows ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::BidMetricsRow>
List of rows, each containing a set of bid metrics.
Corresponds to the JSON property bidMetricsRows
2050 2051 2052 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2050 def bid_metrics_rows @bid_metrics_rows end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListBidMetricsRequest.pageToken field in the subsequent call to the bidMetrics.
list method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
2057 2058 2059 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2057 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2064 2065 2066 2067 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2064 def update!(**args) @bid_metrics_rows = args[:bid_metrics_rows] if args.key?(:bid_metrics_rows) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |