Class: Google::Apis::Adexchangebuyer2V2beta1::ListClientUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::ListClientUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#users ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ClientUser>
The returned list of client users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListClientUsersResponse
constructor
A new instance of ListClientUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListClientUsersResponse
Returns a new instance of ListClientUsersResponse.
2169 2170 2171 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListClientUsersRequest.pageToken field in the subsequent call to the clients.
invitations.list method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
2162 2163 2164 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2162 def next_page_token @next_page_token end |
#users ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ClientUser>
The returned list of client users.
Corresponds to the JSON property users
2167 2168 2169 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2167 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2174 2175 2176 2177 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2174 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @users = args[:users] if args.key?(:users) end |