Class: Google::Apis::Adexchangebuyer2V2beta1::ListImpressionMetricsResponse
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::ListImpressionMetricsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
Response message for listing the metrics that are measured in number of impressions.
Instance Attribute Summary collapse
-
#impression_metrics_rows ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ImpressionMetricsRow>
List of rows, each containing a set of impression metrics.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListImpressionMetricsResponse
constructor
A new instance of ListImpressionMetricsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListImpressionMetricsResponse
Returns a new instance of ListImpressionMetricsResponse.
2429 2430 2431 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#impression_metrics_rows ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ImpressionMetricsRow>
List of rows, each containing a set of impression metrics.
Corresponds to the JSON property impressionMetricsRows
2420 2421 2422 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2420 def impression_metrics_rows @impression_metrics_rows end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListImpressionMetricsRequest.pageToken field in the subsequent call to the
impressionMetrics.list method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
2427 2428 2429 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2427 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2434 2435 2436 2437 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 2434 def update!(**args) @impression_metrics_rows = args[:impression_metrics_rows] if args.key?(:impression_metrics_rows) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |