Class: Google::Apis::Adexchangebuyer2V2beta1::Product
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::Product
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
A product is a segment of inventory that a seller wants to sell. It is associated with certain terms and targeting information which helps the buyer know more about the inventory.
Instance Attribute Summary collapse
-
#available_end_time ⇒ String
The proposed end time for the deal.
-
#available_start_time ⇒ String
Inventory availability dates.
-
#create_time ⇒ String
Creation time.
-
#creator_contacts ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ContactInformation>
Optional contact information for the creator of this product.
-
#display_name ⇒ String
The display name for this product as set by the seller.
-
#has_creator_signed_off ⇒ Boolean
(also: #has_creator_signed_off?)
If the creator has already signed off on the product, then the buyer can finalize the deal by accepting the product as is.
-
#product_id ⇒ String
The unique ID for the product.
-
#product_revision ⇒ Fixnum
The revision number of the product (auto-assigned by Marketplace).
-
#publisher_profile_id ⇒ String
An ID which can be used by the Publisher Profile API to get more information about the seller that created this product.
-
#seller ⇒ Google::Apis::Adexchangebuyer2V2beta1::Seller
Represents a seller of inventory.
-
#syndication_product ⇒ String
The syndication product associated with the deal.
-
#targeting_criterion ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::TargetingCriteria>
Targeting that is shared between the buyer and the seller.
-
#terms ⇒ Google::Apis::Adexchangebuyer2V2beta1::DealTerms
The deal terms specify the details of a Product/deal.
-
#update_time ⇒ String
Time of last update.
-
#web_property_code ⇒ String
The web-property code for the seller.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Product
constructor
A new instance of Product.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Product
Returns a new instance of Product.
3255 3256 3257 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_end_time ⇒ String
The proposed end time for the deal. The field will be truncated to the order
of seconds during serving.
Corresponds to the JSON property availableEndTime
3170 3171 3172 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3170 def available_end_time @available_end_time end |
#available_start_time ⇒ String
Inventory availability dates. The start time will be truncated to seconds
during serving. Thus, a field specified as 3:23:34.456 (HH:mm:ss.SSS) will be
truncated to 3:23:34 when serving.
Corresponds to the JSON property availableStartTime
3177 3178 3179 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3177 def available_start_time @available_start_time end |
#create_time ⇒ String
Creation time.
Corresponds to the JSON property createTime
3182 3183 3184 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3182 def create_time @create_time end |
#creator_contacts ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ContactInformation>
Optional contact information for the creator of this product.
Corresponds to the JSON property creatorContacts
3187 3188 3189 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3187 def creator_contacts @creator_contacts end |
#display_name ⇒ String
The display name for this product as set by the seller.
Corresponds to the JSON property displayName
3192 3193 3194 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3192 def display_name @display_name end |
#has_creator_signed_off ⇒ Boolean Also known as: has_creator_signed_off?
If the creator has already signed off on the product, then the buyer can
finalize the deal by accepting the product as is. When copying to a proposal,
if any of the terms are changed, then auto_finalize is automatically set to
false.
Corresponds to the JSON property hasCreatorSignedOff
3200 3201 3202 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3200 def has_creator_signed_off @has_creator_signed_off end |
#product_id ⇒ String
The unique ID for the product.
Corresponds to the JSON property productId
3206 3207 3208 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3206 def product_id @product_id end |
#product_revision ⇒ Fixnum
The revision number of the product (auto-assigned by Marketplace).
Corresponds to the JSON property productRevision
3211 3212 3213 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3211 def product_revision @product_revision end |
#publisher_profile_id ⇒ String
An ID which can be used by the Publisher Profile API to get more information
about the seller that created this product.
Corresponds to the JSON property publisherProfileId
3217 3218 3219 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3217 def publisher_profile_id @publisher_profile_id end |
#seller ⇒ Google::Apis::Adexchangebuyer2V2beta1::Seller
Represents a seller of inventory. Each seller is identified by a unique Ad
Manager account ID.
Corresponds to the JSON property seller
3223 3224 3225 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3223 def seller @seller end |
#syndication_product ⇒ String
The syndication product associated with the deal.
Corresponds to the JSON property syndicationProduct
3228 3229 3230 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3228 def @syndication_product end |
#targeting_criterion ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::TargetingCriteria>
Targeting that is shared between the buyer and the seller. Each targeting
criterion has a specified key and for each key there is a list of inclusion
value or exclusion values.
Corresponds to the JSON property targetingCriterion
3235 3236 3237 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3235 def targeting_criterion @targeting_criterion end |
#terms ⇒ Google::Apis::Adexchangebuyer2V2beta1::DealTerms
The deal terms specify the details of a Product/deal. They specify things like
price per buyer, the type of pricing model (for example, fixed price, auction)
and expected impressions from the publisher.
Corresponds to the JSON property terms
3242 3243 3244 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3242 def terms @terms end |
#update_time ⇒ String
Time of last update.
Corresponds to the JSON property updateTime
3247 3248 3249 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3247 def update_time @update_time end |
#web_property_code ⇒ String
The web-property code for the seller. This needs to be copied as is when
adding a new deal to a proposal.
Corresponds to the JSON property webPropertyCode
3253 3254 3255 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3253 def web_property_code @web_property_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3260 def update!(**args) @available_end_time = args[:available_end_time] if args.key?(:available_end_time) @available_start_time = args[:available_start_time] if args.key?(:available_start_time) @create_time = args[:create_time] if args.key?(:create_time) @creator_contacts = args[:creator_contacts] if args.key?(:creator_contacts) @display_name = args[:display_name] if args.key?(:display_name) @has_creator_signed_off = args[:has_creator_signed_off] if args.key?(:has_creator_signed_off) @product_id = args[:product_id] if args.key?(:product_id) @product_revision = args[:product_revision] if args.key?(:product_revision) @publisher_profile_id = args[:publisher_profile_id] if args.key?(:publisher_profile_id) @seller = args[:seller] if args.key?(:seller) @syndication_product = args[:syndication_product] if args.key?(:syndication_product) @targeting_criterion = args[:targeting_criterion] if args.key?(:targeting_criterion) @terms = args[:terms] if args.key?(:terms) @update_time = args[:update_time] if args.key?(:update_time) @web_property_code = args[:web_property_code] if args.key?(:web_property_code) end |