Class: Google::Apis::Adexchangebuyer2V2beta1::Proposal
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::Proposal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
Represents a proposal in the Marketplace. A proposal is the unit of negotiation between a seller and a buyer and contains deals which are served. Note: You can't update, create, or otherwise modify Private Auction deals through the API. Fields are updatable unless noted otherwise.
Instance Attribute Summary collapse
-
#billed_buyer ⇒ Google::Apis::Adexchangebuyer2V2beta1::Buyer
Represents a buyer of inventory.
-
#buyer ⇒ Google::Apis::Adexchangebuyer2V2beta1::Buyer
Represents a buyer of inventory.
-
#buyer_contacts ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ContactInformation>
Contact information for the buyer.
-
#buyer_private_data ⇒ Google::Apis::Adexchangebuyer2V2beta1::PrivateData
Buyers are allowed to store certain types of private data in a proposal/deal.
-
#deals ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::Deal>
The deals associated with this proposal.
-
#display_name ⇒ String
The name for the proposal.
-
#is_renegotiating ⇒ Boolean
(also: #is_renegotiating?)
Output only.
-
#is_setup_complete ⇒ Boolean
(also: #is_setup_complete?)
Output only.
-
#last_updater_or_commentor_role ⇒ String
Output only.
-
#notes ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::Note>
Output only.
-
#originator_role ⇒ String
Output only.
-
#private_auction_id ⇒ String
Output only.
-
#proposal_id ⇒ String
Output only.
-
#proposal_revision ⇒ Fixnum
Output only.
-
#proposal_state ⇒ String
Output only.
-
#seller ⇒ Google::Apis::Adexchangebuyer2V2beta1::Seller
Represents a seller of inventory.
-
#seller_contacts ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ContactInformation>
Output only.
-
#terms_and_conditions ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Proposal
constructor
A new instance of Proposal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Proposal
Returns a new instance of Proposal.
3394 3395 3396 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billed_buyer ⇒ Google::Apis::Adexchangebuyer2V2beta1::Buyer
Represents a buyer of inventory. Each buyer is identified by a unique
Authorized Buyers account ID.
Corresponds to the JSON property billedBuyer
3290 3291 3292 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3290 def billed_buyer @billed_buyer end |
#buyer ⇒ Google::Apis::Adexchangebuyer2V2beta1::Buyer
Represents a buyer of inventory. Each buyer is identified by a unique
Authorized Buyers account ID.
Corresponds to the JSON property buyer
3296 3297 3298 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3296 def buyer @buyer end |
#buyer_contacts ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ContactInformation>
Contact information for the buyer.
Corresponds to the JSON property buyerContacts
3301 3302 3303 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3301 def buyer_contacts @buyer_contacts end |
#buyer_private_data ⇒ Google::Apis::Adexchangebuyer2V2beta1::PrivateData
Buyers are allowed to store certain types of private data in a proposal/deal.
Corresponds to the JSON property buyerPrivateData
3306 3307 3308 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3306 def buyer_private_data @buyer_private_data end |
#deals ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::Deal>
The deals associated with this proposal. For Private Auction proposals (whose
deals have NonGuaranteedAuctionTerms), there will only be one deal.
Corresponds to the JSON property deals
3312 3313 3314 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3312 def deals @deals end |
#display_name ⇒ String
The name for the proposal.
Corresponds to the JSON property displayName
3317 3318 3319 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3317 def display_name @display_name end |
#is_renegotiating ⇒ Boolean Also known as: is_renegotiating?
Output only. True if the proposal is being renegotiated.
Corresponds to the JSON property isRenegotiating
3322 3323 3324 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3322 def is_renegotiating @is_renegotiating end |
#is_setup_complete ⇒ Boolean Also known as: is_setup_complete?
Output only. True, if the buyside inventory setup is complete for this
proposal.
Corresponds to the JSON property isSetupComplete
3329 3330 3331 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3329 def is_setup_complete @is_setup_complete end |
#last_updater_or_commentor_role ⇒ String
Output only. The role of the last user that either updated the proposal or
left a comment.
Corresponds to the JSON property lastUpdaterOrCommentorRole
3336 3337 3338 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3336 def last_updater_or_commentor_role @last_updater_or_commentor_role end |
#notes ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::Note>
Output only. The notes associated with this proposal.
Corresponds to the JSON property notes
3341 3342 3343 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3341 def notes @notes end |
#originator_role ⇒ String
Output only. Indicates whether the buyer/seller created the proposal.
Corresponds to the JSON property originatorRole
3346 3347 3348 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3346 def originator_role @originator_role end |
#private_auction_id ⇒ String
Output only. Private auction ID if this proposal is a private auction proposal.
Corresponds to the JSON property privateAuctionId
3351 3352 3353 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3351 def private_auction_id @private_auction_id end |
#proposal_id ⇒ String
Output only. The unique ID of the proposal.
Corresponds to the JSON property proposalId
3356 3357 3358 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3356 def proposal_id @proposal_id end |
#proposal_revision ⇒ Fixnum
Output only. The revision number for the proposal. Each update to the proposal
or the deal causes the proposal revision number to auto-increment. The buyer
keeps track of the last revision number they know of and pass it in when
making an update. If the head revision number on the server has since
incremented, then an ABORTED error is returned during the update operation to
let the buyer know that a subsequent update was made.
Corresponds to the JSON property proposalRevision
3366 3367 3368 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3366 def proposal_revision @proposal_revision end |
#proposal_state ⇒ String
Output only. The current state of the proposal.
Corresponds to the JSON property proposalState
3371 3372 3373 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3371 def proposal_state @proposal_state end |
#seller ⇒ Google::Apis::Adexchangebuyer2V2beta1::Seller
Represents a seller of inventory. Each seller is identified by a unique Ad
Manager account ID.
Corresponds to the JSON property seller
3377 3378 3379 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3377 def seller @seller end |
#seller_contacts ⇒ Array<Google::Apis::Adexchangebuyer2V2beta1::ContactInformation>
Output only. Contact information for the seller.
Corresponds to the JSON property sellerContacts
3382 3383 3384 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3382 def seller_contacts @seller_contacts end |
#terms_and_conditions ⇒ String
Output only. The terms and conditions set by the publisher for this proposal.
Corresponds to the JSON property termsAndConditions
3387 3388 3389 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3387 def terms_and_conditions @terms_and_conditions end |
#update_time ⇒ String
Output only. The time when the proposal was last revised.
Corresponds to the JSON property updateTime
3392 3393 3394 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3392 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3399 def update!(**args) @billed_buyer = args[:billed_buyer] if args.key?(:billed_buyer) @buyer = args[:buyer] if args.key?(:buyer) @buyer_contacts = args[:buyer_contacts] if args.key?(:buyer_contacts) @buyer_private_data = args[:buyer_private_data] if args.key?(:buyer_private_data) @deals = args[:deals] if args.key?(:deals) @display_name = args[:display_name] if args.key?(:display_name) @is_renegotiating = args[:is_renegotiating] if args.key?(:is_renegotiating) @is_setup_complete = args[:is_setup_complete] if args.key?(:is_setup_complete) @last_updater_or_commentor_role = args[:last_updater_or_commentor_role] if args.key?(:last_updater_or_commentor_role) @notes = args[:notes] if args.key?(:notes) @originator_role = args[:originator_role] if args.key?(:originator_role) @private_auction_id = args[:private_auction_id] if args.key?(:private_auction_id) @proposal_id = args[:proposal_id] if args.key?(:proposal_id) @proposal_revision = args[:proposal_revision] if args.key?(:proposal_revision) @proposal_state = args[:proposal_state] if args.key?(:proposal_state) @seller = args[:seller] if args.key?(:seller) @seller_contacts = args[:seller_contacts] if args.key?(:seller_contacts) @terms_and_conditions = args[:terms_and_conditions] if args.key?(:terms_and_conditions) @update_time = args[:update_time] if args.key?(:update_time) end |