Class: Google::Apis::Adexchangebuyer2V2beta1::Seller
- Inherits:
-
Object
- Object
- Google::Apis::Adexchangebuyer2V2beta1::Seller
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/adexchangebuyer2_v2beta1/classes.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb,
lib/google/apis/adexchangebuyer2_v2beta1/representations.rb
Overview
Represents a seller of inventory. Each seller is identified by a unique Ad Manager account ID.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The unique ID for the seller.
-
#sub_account_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Seller
constructor
A new instance of Seller.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Seller
Returns a new instance of Seller.
3756 3757 3758 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
The unique ID for the seller. The seller fills in this field. The seller
account ID is then available to buyer in the product.
Corresponds to the JSON property accountId
3749 3750 3751 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3749 def account_id @account_id end |
#sub_account_id ⇒ String
Output only. Ad manager network code for the seller.
Corresponds to the JSON property subAccountId
3754 3755 3756 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3754 def sub_account_id @sub_account_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3761 3762 3763 3764 |
# File 'lib/google/apis/adexchangebuyer2_v2beta1/classes.rb', line 3761 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @sub_account_id = args[:sub_account_id] if args.key?(:sub_account_id) end |